
#
# Shiny App for nonlinear support vector separation of Pareto optima
# ******************************************************************
#
# requires: rPref, kernlab, rhandsontable, ggplot2
#
# User Interface File
#
# Press "Run App" in RStudio to start the App
#

library(shiny)
library(rhandsontable)

shinyUI(fluidPage(

  titlePanel("Support Vector Separation of Pareto Optima and Level-n tuples"),

  
  tabsetPanel(id="tab",
    tabPanel("Separation",
      sidebarLayout(
        sidebarPanel(
          checkboxInput("show_sep", "Show separation line", value = TRUE),
          sliderInput("level_sep", "Level of the points to separate", min = 2, max = 5, value = 3, step = 1),
          sliderInput("degree", "Degree of SVM kernel for separation", min = 1, max = 5, value = 3, step = 1),
          hr(),
          htmlOutput("state1"),
          hr(),
          h4("Data set configuration"),
          sliderInput("cor", "Correlation value for random data set generator", min = -1, max = 1, value = -0.5, step = 0.1),
          actionButton("recalc", "Randomly generate new data set")
        ),
        mainPanel(
          h4("Separation plot"),
          plotOutput("skylinePlot", width="100%", height="450px"),
          h4("Separation line formula"),
          htmlOutput("state_formula")
        )
      )
    ),
    tabPanel("Tuple editor",
      sidebarLayout(
        sidebarPanel(
          rHandsontableOutput("tbl_tuples", height="500px")
        ),
        mainPanel(
          plotOutput("editorPlot", width="100%", height="450px")
        )
      )
    )
  )


  
))
